@@ -32,40 +32,17 @@ class Inspector:
         if self._frames is not None:
             return self._frames
 
-        self._frames = FrameCollection(self.outer_frames + self.inner_frames)
+        self._frames = FrameCollection()
+
+        tb = self._exception.__traceback__
+
+        while tb:
+            frame_info = inspect.getframeinfo(tb)
+            self._frames.append(Frame(inspect.FrameInfo(tb.tb_frame, *frame_info)))
+            tb = tb.tb_next
 
         return self._frames
 
-    @property
-    def outer_frames(self) -> FrameCollection:
-        if self._outer_frames is not None:
-            return self._outer_frames
-
-        tb = self._exception.__traceback__
-
-        outer_frames = FrameCollection()
-        for frame_info in inspect.getouterframes(tb.tb_frame)[1:]:
-            outer_frames.append(Frame(frame_info))
-
-        self._outer_frames = outer_frames
-
-        return self._outer_frames
-
-    @property
-    def inner_frames(self) -> FrameCollection:
-        if self._inner_frames is not None:
-            return self._inner_frames
-
-        tb = self._exception.__traceback__
-
-        inner_frames = FrameCollection()
-        for frame_info in inspect.getinnerframes(tb):
-            inner_frames.append(Frame(frame_info))
-
-        self._inner_frames = inner_frames
-
-        return self._inner_frames
-
     @property
     def previous_exception(self) -> Optional[Exception]:
         return self._previous_exception
